@@ -74,6 +74,10 @@ else:
 #  This class provides access to the Zymkey within Python
 class Zymkey(object):
    EPHEMERAL_KEY_SLOT = -1
+
+   ## @name Zymkey Context
+   ###@{
+
    ## @brief The class initialization opens and stores an instance of a
    #  Zymkey context
    def __init__(self):
@@ -82,12 +86,17 @@ class Zymkey(object):
       if ret < 0:
          raise AssertionError("bad return code {!r}".format(ret))
 
+   ## @brief The class destructor closes a Zymkey context
    def __del__(self):
       if self._zk_ctx != None:
          ret = self._zkClose(self._zk_ctx)
          if ret < 0:
             raise AssertionError('bad return code %d' % ret)
          self._zk_ctx = None
+   ###@}
+
+   ## @name LED Control
+   ###@{
 
    ## @brief Turn the LED on
    def led_on(self):
@@ -116,6 +125,10 @@ class Zymkey(object):
       ret = self._zkLEDFlash(self._zk_ctx, on_ms, off_ms, num_flashes)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
+   ###@}
+
+   ## @name Random Number Generation
+   ###@{
 
    ## @brief Get some random bytes
    #  @param num_bytes The number of random bytes to get
@@ -135,6 +148,10 @@ class Zymkey(object):
       ret = self._zkCreateRandDataFile(self._zk_ctx, file_path.encode('utf-8'), num_bytes)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
+   ###@}
+
+   ## @name Lock Data
+   ###@{
 
    ## @brief Lock up source (plaintext) data
    #  @details This method encrypts and signs a block of data.
@@ -227,6 +244,10 @@ class Zymkey(object):
          dc = (c_ubyte * dst_data_sz.value).from_address(dst_data.value)
          data_array = bytearray(dc)
          return data_array
+   ###@}
+
+   ## @name Unlock Data
+   ###@{
 
    ## @brief Unlock source (ciphertext) data.
    #  @details This method verifies a locked object signature and
@@ -327,6 +348,10 @@ class Zymkey(object):
             dc = (c_ubyte * dst_data_sz.value).from_address(dst_data.value)
             data_array = bytearray(dc)
             return data_array
+   ###@}
+
+   ## @name ECDSA
+   ###@{
 
    ## @brief Generate a signature using the Zymkey's ECDSA private key.
    #  @param src This parameter contains the digest of the data that
@@ -376,6 +401,8 @@ class Zymkey(object):
    #  @param raise_exception By default, when verification fails a
    #    VerificationError will be raised, unless this is set to False
    #  @param pubkey_slot The key slot to use to verify the signature against. Defaults to the first key slot.
+   #  @param foreign If false, the normal key store is referenced.
+   #  Otherwise, the foreign public key store is referenced.
    #  @returns True for a good verification or False for a bad verification when raise_exception is False
    def verify(self, src, sig, raise_exception=True, pubkey_slot=0, foreign=False):
       sha256 = hashlib.sha256()
@@ -393,6 +420,8 @@ class Zymkey(object):
    #  @param raise_exception By default, when verification fails a
    #    VerificationError will be raised, unless this is set to False
    #  @param pubkey_slot The key slot to use to verify the signature against. Defaults to the first key slot.
+   #  @param foreign If false, the normal key store is referenced.
+   #  Otherwise, the foreign public key store is referenced.
    #  @returns True for a good verification or False for a bad verification when raise_exception is False
    def verify_digest(self, sha256, sig, raise_exception=True, pubkey_slot=0, foreign=False):
         digest_bytes = bytearray(sha256.digest())
@@ -423,8 +452,12 @@ class Zymkey(object):
             return True
         else:
             raise AssertionError('bad return code %d' % ret)
+   ###@}
 
-   ## @brief Derive a key or a pre-master secret from an ECDH operation.
+   ## @name ECDH and KDF
+   ###@{
+
+   ## @brief Derive a key or a pre-master secret from an ECDH operation (model >= HSM6).
    #  @param local_slot This parameter specifies the local key slot to use.
    #  @param peer_pubkey
    #  @param kdf_func_type
@@ -485,8 +518,12 @@ class Zymkey(object):
       dc = (c_ubyte * derived_key_size).from_address(derived_key.value)
       data_array = bytearray(dc)
       return data_array
+   ###@}
 
-   ## @brief Create a file with the PEM-formatted ECDSA public key.
+   ## @name Key Management
+   ###@{
+
+   ## @brief [DEPRECATED] Use create_public_key_file. Create a file with the PEM-formatted ECDSA public key.
    #  @details This method is useful for generating a Certificate
    #           Signing Request.
    #  @param filename The absolute file path where the public key will
@@ -504,13 +541,16 @@ class Zymkey(object):
    #  @param filename The absolute file path where the public key will
    #    be stored in PEM format.
    #  @param slot This parameter specifies the key slot for the public
-   #              key.
+   #              key. Zymkey and HSM4 have slots 0, 1, and 2.
+   #  @param slot_is_foreign
+   #        If true, designates the pubkey slot to come from the foreign
+   #        keystore (model >= HSM6).
    def create_public_key_file(self, filename, slot=0, foreign=False):
       ret = self._zkExportPubKey2File(self._zk_ctx, filename.encode('utf-8'), slot, foreign)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
 
-   ## @brief Retrieves the ECDSA public key as a binary bytearray.
+   ## @brief [DEPRECATED] Use get_public_key. Retrieves the ECDSA public key as a binary bytearray.
    #  @details This method is used to retrieve the public key in binary
    #           form.
    #  @param slot This parameter specifies the key slot for the public
@@ -530,7 +570,8 @@ class Zymkey(object):
    #  @details This method is used to retrieve the public key in binary
    #           form.
    #  @param slot This parameter specifies the key slot for the public
-   #              key.
+   #              key. Zymkey and HSM4 have slots 0, 1, and 2.
+   #  @return Bytearray of the public key
    def get_public_key(self, slot=0, foreign=False):
       dst_data = c_void_p()
       dst_data_sz = c_int()
@@ -542,7 +583,25 @@ class Zymkey(object):
       data_array = bytearray(dc)
       return data_array
 
-   ## @brief Stores a foreign public key on the Zymkey foreign keyring.
+   ## @brief Get a list of the allocated slots in the key store (model >= HSM6).
+   #  @details This method gets a list of the allocated slots in the key
+   #           store.
+   #  @param foreign If True, the allocation list of the foreign key
+   #                 store is returned
+   #  @return the allocation list and the maximum number of keys
+   def get_slot_alloc_list(self, foreign=False):
+      alloc_key_slot_list = c_void_p()
+      alloc_key_slot_list_sz = c_int()
+      max_num_keys = c_int()
+
+      ret = self._zkGetAllocSlotsList(self._zk_ctx, foreign, byref(max_num_keys), byref(alloc_key_slot_list), byref(alloc_key_slot_list_sz))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      dc = (c_int * alloc_key_slot_list_sz.value).from_address(alloc_key_slot_list.value)
+      alloc_keys = list(dc)
+      return alloc_keys, max_num_keys.value
+
+   ## @brief Stores a foreign public key on the Zymkey foreign keyring (model >= HSM6).
    #  @details This method stores a foreign public key onto the Zymkey foreign
    #           public keyring.
    #  @param key_type This parameter indicates the EC curve type that should be
@@ -559,7 +618,7 @@ class Zymkey(object):
          raise AssertionError('bad return code %d' % ret)
       return ret
 
-   ## @brief Disables exporting of a public key at a given slot.
+   ## @brief Disables exporting of a public key at a given slot (model >= HSM6).
    #  @details This method permanently disables exporting a public key from a
    #           given slot.
    #  @param slot This parameter specifies the key slot for the public
@@ -570,7 +629,7 @@ class Zymkey(object):
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
 
-   ## @brief Generates a new key pair.
+   ## @brief Generates a new key pair (model >= HSM6).
    #  @details This method generates a new key pair of the specified type.
    #  @param key_type This parameter indicates the EC curve type that should be
    #                  associated with the new key pair.
@@ -582,20 +641,18 @@ class Zymkey(object):
          raise AssertionError('bad return code %d' % ret)
       return ret
 
-   ## @brief Generates a new ephemeral key pair.
+   ## @brief Generates a new ephemeral key pair (model >= HSM6).
    #  @details This method generates a new ephemeral key pair of the specified
    #           type, overwriting the previous ephemeral key pair.
    #  @param key_type This parameter indicates the EC curve type that should be
    #                  associated with the new key pair.
-   #  @return the slot allocated to the key or less than one for failure.
    def gen_ephemeral_key_pair(self, key_type):
       kt = keyTypes[key_type]
       ret = self._zkGenEphemeralKeyPair(self._zk_ctx, kt)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
-      return ret
 
-   ## @brief Remove a key at the designated slot.
+   ## @brief Remove a key at the designated slot (model >= HSM6).
    #  @details This method removes a key at the designated slot in either the
    #           standard key store or the foreign public keyring.
    #  @param slot This parameter specifies the key slot for the key.
@@ -605,9 +662,8 @@ class Zymkey(object):
       ret = self._zkRemoveKey(self._zk_ctx, slot, foreign)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
-      return ret
 
-   ## @brief Invalidate the ephemeral key.
+   ## @brief Invalidate the ephemeral key (model >= HSM6).
    #  @details This method invalidates the ephemeral key, effectively removing
    #           it from service until a new key is generated.
    def invalidate_ephemeral_key(self, slot, foreign=False):
@@ -615,15 +671,20 @@ class Zymkey(object):
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
       return ret
+   ###@}
 
-   ## @brief Generates a new master seed for creating a new BIP32 wallet.
+   ## @name Digital Wallet (BIP 32/39/44)
+   ###@{
+
+   ## @brief Generates a new master seed for creating a new BIP32 wallet (model >= HSM6).
    #  @details This method generates a new master seed for creating a new BIP32
    #           wallet.
    #  @param key_type This parameter indicates the EC curve type that should be
    #                  associated with the new key pair.
-   #  @param master_gen_key The master generator key used in the derivation of
-   #                        the child key.
-   #  @param wallet_name The name of the wallet that this master seed is attached to
+   #  @param master_gen_key The master generator key (bytearray) used in the
+   #                        derivation of the child key.
+   #  @param wallet_name The name of the wallet (string) that this master seed
+   #                     is attached to.
    #  @param bip39 If true, generate the seed per BIP39 and return the mnemonic
    #               string.
    #  @return a tuple with the slot and the BIP39 mnemonic if specified
@@ -651,7 +712,7 @@ class Zymkey(object):
       else:
           return ret, None
 
-   ## @brief Generates a child key based on a parent key that is in a wallet.
+   ## @brief Generates a child key based on a parent key that is in a wallet (model >= HSM6).
    #  @details This method generates a child key based on a parent key that is
    #           in a wallet.
    #  @param parent_key_slot This parameter specifies the parent key slot. This
@@ -666,7 +727,7 @@ class Zymkey(object):
          raise AssertionError('bad return code %d' % ret)
       return ret
 
-   ## @brief Restore a wallet's master seed based on a BIP39 mnemonic string.
+   ## @brief Restore a wallet's master seed based on a BIP39 mnemonic string (model >= HSM6).
    #  @details This method restores a wallet's master seed based on a BIP39
    #           mnemonic string and a master generator key. This method can be
    #           used in the process of wallet duplication.
@@ -691,7 +752,7 @@ class Zymkey(object):
          raise AssertionError('bad return code %d' % ret)
       return ret
 
-   ## @brief Get a wallet node address from a key slot
+   ## @brief Get a wallet node address from a key slot (model >= HSM6)
    #  @details This method gets a wallet entry's node address from its key slot
    #           assignment. The wallet name and master seed slot are also
    #          returned.
@@ -708,7 +769,7 @@ class Zymkey(object):
        wn = cast(wallet_name, c_char_p)
        return na.value.decode('utf-8'), wn.value.decode('utf-8'), master_seed_slot.value
 
-   ## @brief Look up a wallet key slot number from a node address
+   ## @brief Look up a wallet key slot number from a node address (model >= HSM6)
    #  @details This method gets a wallet key slot number from its node address
    #           and wallet name or master seed key slot. Either the wallet name
    #           or the master seed slot must be present.
@@ -729,24 +790,10 @@ class Zymkey(object):
        if ret < 0:
            raise AssertionError('bad return code %d' % ret)
        return key_slot.value
+   ###@}
 
-   ## @brief Get a list of the allocated slots in the key store
-   #  @details This method gets a list of the allocated slots in the key
-   #           store.
-   #  @param foreign If True, the allocation list of the foreign key
-   #                 store is returned
-   #  @return the allocation list and the maximum number of keys
-   def get_slot_alloc_list(self, foreign=False):
-      alloc_key_slot_list = c_void_p()
-      alloc_key_slot_list_sz = c_int()
-      max_num_keys = c_int()
-
-      ret = self._zkGetAllocSlotsList(self._zk_ctx, foreign, byref(max_num_keys), byref(alloc_key_slot_list), byref(alloc_key_slot_list_sz))
-      if ret < 0:
-         raise AssertionError('bad return code %d' % ret)
-      dc = (c_int * alloc_key_slot_list_sz.value).from_address(alloc_key_slot_list.value)
-      alloc_keys = list(dc)
-      return alloc_keys, max_num_keys.value
+   ## @name Adminstration
+   ###@{
 
    ## @brief Sets the i2c address of the Zymkey (i2c versions only)
    #  @details This method should be called if the i2c address of the
@@ -764,6 +811,10 @@ class Zymkey(object):
       ret = self._zkSetI2CAddr(self._zk_ctx, addr_c_int)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
+   ###@}
+
+   ## @name Accelerometer
+   ###@{
 
    ## @brief Sets the sensitivity of tap operations.
    #  @details This method permits setting the sensitivity of the tap
@@ -796,20 +847,6 @@ class Zymkey(object):
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
 
-   ## @brief Get current GMT time
-   #  @details This function is called to get the time directly from a
-   #           Zymkey's Real Time Clock (RTC)
-   # @param precise If true, this API returns the time after the next second
-   #        falls. This means that the caller could be blocked up to one second.
-   #        If False, the API returns immediately with the current time reading.
-   # @returns The time in seconds from the epoch (Jan. 1, 1970)
-   def get_time(self, precise=False):
-      epoch_sec = c_int()
-      ret = self._zkGetTime(self._zk_ctx, byref(epoch_sec), precise)
-      if ret < 0:
-         raise AssertionError('bad return code %d' % ret)
-      return epoch_sec.value
-
    ## @brief Wait for tap event
    #  @brief Wait for a tap event to be detected
    #  @details This function is called in order to wait for a tap event to occur.
@@ -858,32 +895,71 @@ class Zymkey(object):
       yret = self.ZymkeyAccelAxisData(y.g, y.tapDirection)
       zret = self.ZymkeyAccelAxisData(z.g, z.tapDirection)
       return xret, yret, zret
+   ###@}
 
-   ## @brief Wait for a perimeter breach event to be detected
-   #  @details This function is called in order to wait for a perimeter breach
-   #           event to occur. This function blocks the calling thread unless
-   #           called with a timeout of zero.
-   #  @param timeout_ms
-   #         (input) The maximum amount of time in milliseconds to wait for a tap
-   #         event to arrive.
-   def wait_for_perimeter_event(self, timeout_ms=-1):
-      ret = self._zkWaitForPerimeterEvent(self._zk_ctx, timeout_ms)
-      if ret == -errno.ETIMEDOUT:
-         raise ZymkeyTimeoutError('wait timed out')
+   ## @name Time
+   ###@{
+
+   ## @brief Get current GMT time
+   #  @details This function is called to get the time directly from a
+   #           Zymkey's Real Time Clock (RTC)
+   # @param precise If true, this API returns the time after the next second
+   #        falls. This means that the caller could be blocked up to one second.
+   #        If False, the API returns immediately with the current time reading.
+   # @returns The time in seconds from the epoch (Jan. 1, 1970)
+   def get_time(self, precise=False):
+      epoch_sec = c_int()
+      ret = self._zkGetTime(self._zk_ctx, byref(epoch_sec), precise)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
+      return epoch_sec.value
+   ###@}
+
+   ## @name Binding Management
+   ###@{
+
+   ## @brief Set soft binding lock.
+   # @details This function locks the binding for a specific HSM. This API is
+   #          only valid for HSM series products.
+   # @exceptions AssertionError
+   def lock_binding(self):
+      ret = self._zkLockBinding(self._zk_ctx)
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+
+   ## @brief Get current binding info
+   # @details This function gets the current binding lock state as well as the
+   #          current binding state. This API is only valid for devices in the HSM
+   #          family.
+   # @param binding_is_locked
+   #        (output) Binary value which expresses the current binding lock state.
+   #        is_bound
+   #        (output) Binary value which expresses the current bind state.
+   # @returns locked, is_bound
+   # @exceptions AssertionError
+   def get_current_binding_info(self):
+      locked = c_bool()
+      is_bound = c_bool()
+      ret = self._zkGetCurrentBindingInfo(self._zk_ctx, byref(locked), byref(is_bound))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      return locked.value, is_bound.value
+   ###@}
+
+   ## @name Perimeter Breach
+   ###@{
 
    ## @brief Set perimeter breach action
    #  @details This function specifies the action to take when a perimeter breach
    #           event occurs. The possible actions are any combination of:
-   #               1. Notify host
-   #               2. Zymkey self-destruct
+   #               - Notify host
+   #               - Zymkey self-destruct
    #  @param channel
-   #         (input) The channel that the action flags will be applied to
-   #         action_flags
-   #         (input) The actions to apply to the perimeter event channel:
-   #                 1. Notify (ZK_PERIMETER_EVENT_ACTION_NOTIFY)
-   #                 2. Self-destruct (ZK_PERIMETER_EVENT_ACTION_SELF_DESTRUCT)
+   #         (input) The channel (0 or 1) that the action flags will be applied to
+   #  @param action_notify
+   #         (input) Set a perimeter breach to notify. (default = True)
+   #  @param action_self_destruct
+   #         (input) Set a perimeter breach to self destruct. (default = False)
    def set_perimeter_event_actions(self, channel, action_notify=True, action_self_destruct=False):
       actions = 0
       if action_notify:
@@ -894,9 +970,48 @@ class Zymkey(object):
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
 
+   ## @brief Set the digital perimeter detect low power period (model >= HSM6).
+   #  @details This function sets the digital perimeter detect low power period (microseconds).
+   #  @param lp_period The perimeter detect low power period in microseconds.
+   def set_digital_perimeter_lp_period(self, lp_period):
+      ret = self._zkSetDigitalPerimeterDetectLPPeriod(self._zk_ctx, lp_period)
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+
+   ## @brief Set the low power max number of bits (model >= HSM6).
+   #  @details This function sets the digital perimeter detect low power max number of bits
+   #  @param max_num_bits The perimeter detect low power max number of bits
+   def set_digital_perimeter_lp_max_bits(self, max_num_bits):
+      ret = self._zkSetDigitalPerimeterDetectLPMaxBits(self._zk_ctx, max_num_bits)
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+
+   ## @brief Set the digital perimeter detect delays (model >= HSM6).
+   #  @details This function sets the digital perimeter detect delay values.
+   #  @param min_delay_ns The minimum delay in nanoseconds
+   #  @param max_delay_ns The maximum delay in nanoseconds
+   def set_digital_perimeter_delays(self, min_delay_ns, max_delay_ns):
+      ret = self._zkSetDigitalPerimeterDetectDelays(self._zk_ctx, min_delay_ns, max_delay_ns)
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+
+   ## @brief Wait for a perimeter breach event to be detected
+   #  @details This function is called in order to wait for a perimeter breach
+   #           event to occur. This function blocks the calling thread unless
+   #           called with a timeout of zero.
+   #  @param timeout_ms
+   #         (input) The maximum amount of time in milliseconds to wait for a perimeter breach
+   #         event to arrive.
+   def wait_for_perimeter_event(self, timeout_ms=-1):
+      ret = self._zkWaitForPerimeterEvent(self._zk_ctx, timeout_ms)
+      if ret == -errno.ETIMEDOUT:
+         raise ZymkeyTimeoutError('wait timed out')
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+
    ##  @brief Get current perimeter detect info.
    #  @details This function gets the timestamp of the first perimeter detect
-   #           event for the given channel
+   #           event for the given channel. The index corresponds to the channel specified in set_perimeter_event_actions.
    #  @returns The array of timestamps for each channel for the first detected
    #           event in epoch seconds
    def get_perimeter_detect_info(self):
@@ -921,6 +1036,80 @@ class Zymkey(object):
       ret = self._zkClearPerimeterDetectEvents(self._zk_ctx)
       if ret < 0:
          raise AssertionError('bad return code %d' % ret)
+   ###@}
+
+   ## @name Module Info
+   ###@{
+
+   ## @brief Get current CPU temperature (model >= HSM6).
+   #  @details This function gets the current HSM CPU temperature.
+   #  @returns The CPU temperature in celsius as a float
+   def get_cpu_temp(self):
+      temp = c_float()
+      ret = self._zkGetCPUTemp(self._zk_ctx, byref(temp))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      return temp.value
+
+   ## @brief Get RTC drift (model >= HSM6).
+   #  @details This function gets the current RTC drift.
+   #  @returns The RTC drift as a float
+   def get_rtc_drift(self):
+      drift = c_float()
+      ret = self._zkGetRTCDrift(self._zk_ctx, byref(drift))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      return drift.value
+
+   ## @brief Get current battery voltage (model >= HSM6).
+   #  @details This function gets the current battery voltage.
+   #  @returns The battery voltage as a float
+   def get_batt_volt(self):
+      volt = c_float()
+      ret = self._zkGetBatteryVoltage(self._zk_ctx, byref(volt))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      return volt.value
+
+   ###@}
+
+   ## @name Model Information
+   ###@{
+   ## @brief Get Zymkey model number
+   #  @details This function gets the Zymkey model number.
+   #  @returns The model number as a string.
+   def get_model_number(self):
+      model = c_void_p()
+      ret = self._zkGetModelNumberString(self._zk_ctx, byref(model))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      model_str = cast(model, c_char_p)
+      return model_str.value.decode('utf-8')
+
+   ## @brief Get Zymkey firmware version
+   #  @details This function gets the Zymkey firmware version.
+   #  @returns The firmware version as a string.
+   def get_firmware_version(self):
+      fw = c_void_p()
+      ret = self._zkGetFirmwareVersionString(self._zk_ctx, byref(fw))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      fw_str = cast(fw, c_char_p)
+      return fw_str.value.decode('utf-8')
+
+   ## @brief Get Zymkey serial number
+   #  @details This function gets the Zymkey serial number.
+   #  @returns The serial number as a string.
+   def get_serial_number(self):
+      sn = c_void_p()
+      ret = self._zkGetSerialNumberString(self._zk_ctx, byref(sn))
+      if ret < 0:
+         raise AssertionError('bad return code %d' % ret)
+      sn_str = cast(sn, c_char_p)
+      return sn_str.value.decode('utf-8')
+   ###@}
+
+
 
    # Interfaces to the C library
    _zkOpen = zkalib.zkOpen
@@ -1068,6 +1257,38 @@ class Zymkey(object):
       _zkExportPubKey.restype = c_int
       _zkExportPubKey.argtypes = [c_void_p, POINTER(c_void_p), POINTER(c_int), c_int, c_bool]
 
+      _zkLockBinding = zkalib.zkLockBinding
+      _zkLockBinding.restype = c_int
+      _zkLockBinding.argtypes = [c_void_p]
+
+      _zkGetCurrentBindingInfo = zkalib.zkGetCurrentBindingInfo
+      _zkGetCurrentBindingInfo.restype = c_int
+      _zkGetCurrentBindingInfo.argtypes = [c_void_p, POINTER(c_bool), POINTER(c_bool)]
+
+      _zkGetCPUTemp = zkalib.zkGetCPUTemp
+      _zkGetCPUTemp.restype = c_int
+      _zkGetCPUTemp.argtypes = [c_void_p, POINTER(c_float)]
+
+      _zkGetRTCDrift = zkalib.zkGetRTCDrift
+      _zkGetRTCDrift.restype = c_int
+      _zkGetRTCDrift.argtypes = [c_void_p, POINTER(c_float)]
+
+      _zkGetBatteryVoltage = zkalib.zkGetBatteryVoltage
+      _zkGetBatteryVoltage.restype = c_int
+      _zkGetBatteryVoltage.argtypes = [c_void_p, POINTER(c_float)]
+
+      _zkSetDigitalPerimeterDetectLPPeriod = zkalib.zkSetDigitalPerimeterDetectLPPeriod
+      _zkSetDigitalPerimeterDetectLPPeriod.restype = c_int
+      _zkSetDigitalPerimeterDetectLPPeriod.argtypes = [c_void_p, c_int]
+
+      _zkSetDigitalPerimeterDetectLPMaxBits = zkalib.zkSetDigitalPerimeterDetectLPMaxBits
+      _zkSetDigitalPerimeterDetectLPMaxBits.restype = c_int
+      _zkSetDigitalPerimeterDetectLPMaxBits.argtypes = [c_void_p, c_int]
+
+      _zkSetDigitalPerimeterDetectDelays = zkalib.zkSetDigitalPerimeterDetectDelays
+      _zkSetDigitalPerimeterDetectDelays.restype = c_int
+      _zkSetDigitalPerimeterDetectDelays.argtypes = [c_void_p, c_int, c_int]
+
    except:
       pass
 
@@ -1114,3 +1335,15 @@ class Zymkey(object):
    _zkSetPerimeterEventAction = zkalib.zkSetPerimeterEventAction
    _zkSetPerimeterEventAction.restype = c_int
    _zkSetPerimeterEventAction.argtypes = [c_void_p, c_int, c_int]
+
+   _zkGetModelNumberString = zkalib.zkGetModelNumberString
+   _zkGetModelNumberString.restype = c_int
+   _zkGetModelNumberString.argtypes = [c_void_p, POINTER(c_void_p)]
+
+   _zkGetFirmwareVersionString = zkalib.zkGetFirmwareVersionString
+   _zkGetFirmwareVersionString.restype = c_int
+   _zkGetFirmwareVersionString.argtypes = [c_void_p, POINTER(c_void_p)]
+
+   _zkGetSerialNumberString = zkalib.zkGetSerialNumberString
+   _zkGetSerialNumberString.restype = c_int
+   _zkGetSerialNumberString.argtypes = [c_void_p, POINTER(c_void_p)]
